
#ifndef AKONADI_KABC_EXPORT_H
#define AKONADI_KABC_EXPORT_H

#ifdef AKONADI_KABC_STATIC_DEFINE
#  define AKONADI_KABC_EXPORT
#  define AKONADI_KABC_NO_EXPORT
#else
#  ifndef AKONADI_KABC_EXPORT
#    ifdef akonadi_kabc
        /* We are building this library */
#      define AKONADI_KABC_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define AKONADI_KABC_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef AKONADI_KABC_NO_EXPORT
#    define AKONADI_KABC_NO_EXPORT 
#  endif
#endif

#ifndef AKONADI_KABC_DEPRECATED
#  define AKONADI_KABC_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef AKONADI_KABC_DEPRECATED_EXPORT
#  define AKONADI_KABC_DEPRECATED_EXPORT AKONADI_KABC_EXPORT AKONADI_KABC_DEPRECATED
#endif

#ifndef AKONADI_KABC_DEPRECATED_NO_EXPORT
#  define AKONADI_KABC_DEPRECATED_NO_EXPORT AKONADI_KABC_NO_EXPORT AKONADI_KABC_DEPRECATED
#endif

#define DEFINE_NO_DEPRECATED 0
#if DEFINE_NO_DEPRECATED
# define AKONADI_KABC_NO_DEPRECATED
#endif

#endif
